import React, { useState, useEffect } from "react";
import { Table, Tag, Space, Modal, Select, Spin } from "antd";

import PropTypes from "prop-types";
import { useClient } from "../../contexts/Client";
import { useIParams } from "../../contexts/IParams";
import { Button } from "antd";
import { Navigate, useNavigate } from "react-router-dom";
const { Option } = Select;

const columns = [
  {
    title: "Produto",
    dataIndex: "product",
    key: "product",
  },
  {
    title: "Valor",
    dataIndex: "amount",
    key: "product",
  },
  {
    title: "Action",
    key: "action",
    render: (text, record) => (
      <Space size="middle">
        <a>Edit</a>
        <a>Delete</a>
      </Space>
    ),
  },
];

const data = [
  {
    key: "1",
    product: "Administração",
    amount: "R$ 1.000,00",
  },
];

const DealProducts = () => {
  const [loaded, setLoaded] = useState(false);
  const [products, setProducts] = useState([]);
  const { client } = useClient();
  const { iParams } = useIParams();
  const [deal, setDeal] = useState(null);
  const navigate = useNavigate();
  const [modalVisible, setModalVisible] = useState(false);
  const [modalProductSelected, setModalProductSelected] = useState("");

  const handleModalOk = () => {
    try {
      navigate("/iframe/index.html/product/administracao");
    } catch (error) {
      console.error(error);
    }
  };

  useEffect(() => {
    (async () => {
      try {
        const {
          currentEntityInfo: { currentEntityId },
        } = await client.data.get("currentEntityInfo");

        const options = {
          headers: { Authorization: "Token token=<%= iparam.apiKey %>" },
        };
        const { response } = await client.request.get(
          `https://${iParams.domainName}.myfreshworks.com/crm/sales/api/deals/${currentEntityId}?include=contacts`,
          options
        );
        const _deal = JSON.parse(response);
        setDeal(_deal);

        setProducts(data);
        setLoaded(true);
      } catch (error) {
        console.error(error);
      }
    })();
  }, []);

  return (
    <div style={{ margin: "1%" }}>
      {loaded ? (
        <div>
          <div style={{ textAlign: "end" }}>
            <Button
              onClick={() => setModalVisible(true)}
              type="primary"
              style={{
                marginBottom: 16,
              }}
              disabled={!loaded}
            >
              Adicionar produto
            </Button>
          </div>
          <Table columns={columns} dataSource={products} pagination={false} />

          <Modal
            title="Selecione o produto"
            visible={modalVisible}
            onOk={handleModalOk}
            onCancel={() => {
              setModalVisible(false);
            }}
          >
            <Select
              style={{ width: "100%" }}
              onChange={(value) => setModalProductSelected(value)}
            >
              <Option value="administracao">
                Administração de fundos e custódia
              </Option>
              <Option value="prateleira">Prateleira</Option>
              <Option value="escrituracao">Escrituração</Option>
            </Select>
          </Modal>
        </div>
      ) : (
        <Space
          direction="horizontal"
          style={{ width: "100%", justifyContent: "center" }}
        >
          <Spin tip="Loading..." />
        </Space>
      )}
    </div>
  );
};

DealProducts.propTypes = {
  client: PropTypes.object,
};

export default DealProducts;
